;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "no-littering" "20260706.850"
  "Help keeping ~/.config/emacs clean."
  '((emacs  "28.1")
    (compat "31.0"))
  :url "https://github.com/emacscollective/no-littering"
  :commit "fa0801e5a1135cdb5ba525869f578cea87e8db0e"
  :revdesc "fa0801e5a113"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.no-littering@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.no-littering@jonas.bernoulli.dev")))
